package com.cf.cs.base.misc;


import com.cf.cs.base.pojo.po.ApiContext;

/**
 * The type Api context utils.
 *
 * @author xajhuang @163.com
 */
public class ApiContextUtils {
    private ApiContextUtils() {
        throw new AssertionError("Instantiating utility class.");
    }

    private static final ThreadLocal<ApiContext> API_CONTEXT = new ThreadLocal<>();

    /**
     * Get api context.
     *
     * @return the api context
     */
    public static ApiContext get() {
        ApiContext context = API_CONTEXT.get();
        if (context == null) {
            context = new ApiContext();
            API_CONTEXT.set(context);
        }
        return context;
    }

    /**
     * Sets request info.
     *
     * @param reqBody the req body
     * @param reqTime the req time
     */
    public static void setRequestInfo(String reqBody, Long reqTime) {
        ApiContext context = get();
        context.setRequestBody(reqBody);
        context.setRequestTime(reqTime);
    }

    public static String getLanguare() {
        return HelperUtils.stringNotEmptyOrNull(get().getReqLocal()) ? get().getReqLocal() : "zh_CN";
    }

    /**
     * Sets request local.
     *
     * @param local the local
     */
    public static void setRequestLocal(String local) {
        ApiContext context = get();
        context.setReqLocal(local);
    }

    /**
     * Sets jwt user info.
     *
     * @param jwt      the jwt
     * @param username the username
     * @param uid      the uid
     * @param id       the id
     */
    public static void setJwtUserInfo(String jwt, String username, String uid, Long id) {
        ApiContext context = get();
        context.setJwt(jwt);
        context.setUsername(username);
        context.setUid(uid);
        context.setId(id);
    }

    /**
     * Clear.
     */
    public static void clear() {
        API_CONTEXT.remove();
    }
}
